@@ -12,7 +12,7 @@ def main(fileName, name='main'):
     stream = CommonTokenStream(lexer)
     parser = PytovParser(stream)
     tree = parser.parse()
-    from PytovInterpreter import PytovInterpreter
+    from pytov.PytovInterpreter import PytovInterpreter
     visitor = PytovInterpreter(fileName, name)
     visitor.visit(tree)
     return visitor
